@@ -21,7 +21,7 @@ elif uname -m | grep -E -q 'mips64'; then
 else
     export TOOLDIR=i386
 fi
-export PATH="./tool/$TOOLDIR:$PATH"
+export PATH="$OLDDIR/tool/$TOOLDIR:$PATH"
 
 
 echo ''
@@ -32,4 +32,5 @@ echo "      https://www.ventoy.net"
 echo '**********************************************'
 echo ''
 
+
 ./tool/VentoyWorker.sh $*
